@@ -8,13 +8,17 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_iotevents._jsii
+import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
+import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-iotevents-actions",
-    "1.147.0",
+    "1.148.0",
     __name__[0:-6],
-    "aws-iotevents-actions@1.147.0.jsii.tgz",
+    "aws-iotevents-actions@1.148.0.jsii.tgz",
 )
 
 __all__ = [
